import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import java.nio.charset
import java.nio.file.attribute
import java.time
import java.util
import java.util.stream

class Adler32(Checksum):
    def __init__(self) -> None: ...
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, buffer: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def update(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def update(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class CRC32(Checksum):
    def __init__(self) -> None: ...
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, buffer: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def update(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def update(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class CRC32C(Checksum):
    def __init__(self) -> None: ...
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, buffer: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def update(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class CheckedInputStream(java.io.FilterInputStream):
    def __init__(self, in_: java.io.InputStream, cksum: Checksum, /) -> None: ...
    def getChecksum(self) -> Checksum: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class CheckedOutputStream(java.io.FilterOutputStream):
    def __init__(self, out: java.io.OutputStream, cksum: Checksum, /) -> None: ...
    def getChecksum(self) -> Checksum: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class Checksum(java.lang.Object):
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, buffer: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def update(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def update(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

class DataFormatException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class Deflater(java.lang.Object):
    BEST_COMPRESSION: typing.ClassVar[int] = ...
    BEST_SPEED: typing.ClassVar[int] = ...
    DEFAULT_COMPRESSION: typing.ClassVar[int] = ...
    DEFAULT_STRATEGY: typing.ClassVar[int] = ...
    DEFLATED: typing.ClassVar[int] = ...
    FILTERED: typing.ClassVar[int] = ...
    FULL_FLUSH: typing.ClassVar[int] = ...
    HUFFMAN_ONLY: typing.ClassVar[int] = ...
    NO_COMPRESSION: typing.ClassVar[int] = ...
    NO_FLUSH: typing.ClassVar[int] = ...
    SYNC_FLUSH: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, level: int | java.jint | java.lang.Integer, nowrap: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def deflate(self, output: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def deflate(self, output: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def deflate(self, output: java.nio.ByteBuffer, flush: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def deflate(self, output: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def deflate(self, output: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, flush: int | java.jint | java.lang.Integer, /) -> int: ...
    def end(self) -> None: ...
    def finish(self) -> None: ...
    def finished(self) -> bool: ...
    def getAdler(self) -> int: ...
    def getBytesRead(self) -> int: ...
    def getBytesWritten(self) -> int: ...
    def getTotalIn(self) -> int: ...
    def getTotalOut(self) -> int: ...
    def needsInput(self) -> bool: ...
    def reset(self) -> None: ...
    @typing.overload
    def setDictionary(self, dictionary: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def setDictionary(self, dictionary: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setDictionary(self, dictionary: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setInput(self, input: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def setInput(self, input: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setInput(self, input: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLevel(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStrategy(self, strategy: int | java.jint | java.lang.Integer, /) -> None: ...

class DeflaterInputStream(java.io.FilterInputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    def_: Deflater = ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, defl: Deflater, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, defl: Deflater, bufLen: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, limit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class DeflaterOutputStream(java.io.FilterOutputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    def_: Deflater = ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, def_: Deflater, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, syncFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, def_: Deflater, size: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, def_: Deflater, syncFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, def_: Deflater, size: int | java.jint | java.lang.Integer, syncFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def close(self) -> None: ...
    def deflate(self) -> None: ...
    def finish(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class GZIPInputStream(InflaterInputStream):
    GZIP_MAGIC: typing.ClassVar[int] = ...
    crc: CRC32 = ...
    eos: bool = ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def read(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...

class GZIPOutputStream(DeflaterOutputStream):
    crc: CRC32 = ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, syncFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, size: int | java.jint | java.lang.Integer, syncFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def finish(self) -> None: ...
    def write(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class Inflater(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, nowrap: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def end(self) -> None: ...
    def finished(self) -> bool: ...
    def getAdler(self) -> int: ...
    def getBytesRead(self) -> int: ...
    def getBytesWritten(self) -> int: ...
    def getRemaining(self) -> int: ...
    def getTotalIn(self) -> int: ...
    def getTotalOut(self) -> int: ...
    @typing.overload
    def inflate(self, output: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def inflate(self, output: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def inflate(self, output: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def needsDictionary(self) -> bool: ...
    def needsInput(self) -> bool: ...
    def reset(self) -> None: ...
    @typing.overload
    def setDictionary(self, dictionary: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def setDictionary(self, dictionary: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setDictionary(self, dictionary: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setInput(self, input: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def setInput(self, input: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setInput(self, input: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class InflaterInputStream(java.io.FilterInputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    closed: bool = ...
    inf: Inflater = ...
    len: int = ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, inf: Inflater, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, inf: Inflater, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def fill(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class InflaterOutputStream(java.io.FilterOutputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    inf: Inflater = ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, infl: Inflater, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, infl: Inflater, bufLen: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def finish(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class ZipEntry(java.lang.Cloneable):
    CENATT: typing.ClassVar[int] = ...
    CENATX: typing.ClassVar[int] = ...
    CENCOM: typing.ClassVar[int] = ...
    CENCRC: typing.ClassVar[int] = ...
    CENDSK: typing.ClassVar[int] = ...
    CENEXT: typing.ClassVar[int] = ...
    CENFLG: typing.ClassVar[int] = ...
    CENHDR: typing.ClassVar[int] = ...
    CENHOW: typing.ClassVar[int] = ...
    CENLEN: typing.ClassVar[int] = ...
    CENNAM: typing.ClassVar[int] = ...
    CENOFF: typing.ClassVar[int] = ...
    CENSIG: typing.ClassVar[int] = ...
    CENSIZ: typing.ClassVar[int] = ...
    CENTIM: typing.ClassVar[int] = ...
    CENVEM: typing.ClassVar[int] = ...
    CENVER: typing.ClassVar[int] = ...
    DEFLATED: typing.ClassVar[int] = ...
    ENDCOM: typing.ClassVar[int] = ...
    ENDHDR: typing.ClassVar[int] = ...
    ENDOFF: typing.ClassVar[int] = ...
    ENDSIG: typing.ClassVar[int] = ...
    ENDSIZ: typing.ClassVar[int] = ...
    ENDSUB: typing.ClassVar[int] = ...
    ENDTOT: typing.ClassVar[int] = ...
    EXTCRC: typing.ClassVar[int] = ...
    EXTHDR: typing.ClassVar[int] = ...
    EXTLEN: typing.ClassVar[int] = ...
    EXTSIG: typing.ClassVar[int] = ...
    EXTSIZ: typing.ClassVar[int] = ...
    LOCCRC: typing.ClassVar[int] = ...
    LOCEXT: typing.ClassVar[int] = ...
    LOCFLG: typing.ClassVar[int] = ...
    LOCHDR: typing.ClassVar[int] = ...
    LOCHOW: typing.ClassVar[int] = ...
    LOCLEN: typing.ClassVar[int] = ...
    LOCNAM: typing.ClassVar[int] = ...
    LOCSIG: typing.ClassVar[int] = ...
    LOCSIZ: typing.ClassVar[int] = ...
    LOCTIM: typing.ClassVar[int] = ...
    LOCVER: typing.ClassVar[int] = ...
    STORED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, e: ZipEntry, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getComment(self) -> str: ...
    def getCompressedSize(self) -> int: ...
    def getCrc(self) -> int: ...
    def getCreationTime(self) -> java.nio.file.attribute.FileTime: ...
    def getExtra(self) -> java.chaquopy.JavaArrayJByte: ...
    def getLastAccessTime(self) -> java.nio.file.attribute.FileTime: ...
    def getLastModifiedTime(self) -> java.nio.file.attribute.FileTime: ...
    def getMethod(self) -> int: ...
    def getName(self) -> str: ...
    def getSize(self) -> int: ...
    def getTime(self) -> int: ...
    def getTimeLocal(self) -> java.time.LocalDateTime: ...
    def hashCode(self) -> int: ...
    def isDirectory(self) -> bool: ...
    def setComment(self, comment: str | java.lang.String, /) -> None: ...
    def setCompressedSize(self, csize: int | java.jlong | java.lang.Long, /) -> None: ...
    def setCrc(self, crc: int | java.jlong | java.lang.Long, /) -> None: ...
    def setCreationTime(self, time: java.nio.file.attribute.FileTime, /) -> ZipEntry: ...
    def setExtra(self, extra: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def setLastAccessTime(self, time: java.nio.file.attribute.FileTime, /) -> ZipEntry: ...
    def setLastModifiedTime(self, time: java.nio.file.attribute.FileTime, /) -> ZipEntry: ...
    def setMethod(self, method: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSize(self, size: int | java.jlong | java.lang.Long, /) -> None: ...
    def setTime(self, time: int | java.jlong | java.lang.Long, /) -> None: ...
    def setTimeLocal(self, time: java.time.LocalDateTime, /) -> None: ...
    def toString(self) -> str: ...

class ZipError(java.lang.InternalError):
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class ZipException(java.io.IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class ZipFile(java.io.Closeable):
    CENATT: typing.ClassVar[int] = ...
    CENATX: typing.ClassVar[int] = ...
    CENCOM: typing.ClassVar[int] = ...
    CENCRC: typing.ClassVar[int] = ...
    CENDSK: typing.ClassVar[int] = ...
    CENEXT: typing.ClassVar[int] = ...
    CENFLG: typing.ClassVar[int] = ...
    CENHDR: typing.ClassVar[int] = ...
    CENHOW: typing.ClassVar[int] = ...
    CENLEN: typing.ClassVar[int] = ...
    CENNAM: typing.ClassVar[int] = ...
    CENOFF: typing.ClassVar[int] = ...
    CENSIG: typing.ClassVar[int] = ...
    CENSIZ: typing.ClassVar[int] = ...
    CENTIM: typing.ClassVar[int] = ...
    CENVEM: typing.ClassVar[int] = ...
    CENVER: typing.ClassVar[int] = ...
    ENDCOM: typing.ClassVar[int] = ...
    ENDHDR: typing.ClassVar[int] = ...
    ENDOFF: typing.ClassVar[int] = ...
    ENDSIG: typing.ClassVar[int] = ...
    ENDSIZ: typing.ClassVar[int] = ...
    ENDSUB: typing.ClassVar[int] = ...
    ENDTOT: typing.ClassVar[int] = ...
    EXTCRC: typing.ClassVar[int] = ...
    EXTHDR: typing.ClassVar[int] = ...
    EXTLEN: typing.ClassVar[int] = ...
    EXTSIG: typing.ClassVar[int] = ...
    EXTSIZ: typing.ClassVar[int] = ...
    LOCCRC: typing.ClassVar[int] = ...
    LOCEXT: typing.ClassVar[int] = ...
    LOCFLG: typing.ClassVar[int] = ...
    LOCHDR: typing.ClassVar[int] = ...
    LOCHOW: typing.ClassVar[int] = ...
    LOCLEN: typing.ClassVar[int] = ...
    LOCNAM: typing.ClassVar[int] = ...
    LOCSIG: typing.ClassVar[int] = ...
    LOCSIZ: typing.ClassVar[int] = ...
    LOCTIM: typing.ClassVar[int] = ...
    LOCVER: typing.ClassVar[int] = ...
    OPEN_DELETE: typing.ClassVar[int] = ...
    OPEN_READ: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, file: java.io.File, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: java.io.File, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, file: java.io.File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, file: java.io.File, mode: int | java.jint | java.lang.Integer, charset: java.nio.charset.Charset, /) -> None: ...
    def close(self) -> None: ...
    def entries(self) -> java.util.Enumeration[ZipEntry]: ...
    def getComment(self) -> str: ...
    def getEntry(self, name: str | java.lang.String, /) -> ZipEntry: ...
    def getInputStream(self, entry: ZipEntry, /) -> java.io.InputStream: ...
    def getName(self) -> str: ...
    def size(self) -> int: ...
    def stream(self) -> java.util.stream.Stream[ZipEntry]: ...

class ZipInputStream(InflaterInputStream):
    CENATT: typing.ClassVar[int] = ...
    CENATX: typing.ClassVar[int] = ...
    CENCOM: typing.ClassVar[int] = ...
    CENCRC: typing.ClassVar[int] = ...
    CENDSK: typing.ClassVar[int] = ...
    CENEXT: typing.ClassVar[int] = ...
    CENFLG: typing.ClassVar[int] = ...
    CENHDR: typing.ClassVar[int] = ...
    CENHOW: typing.ClassVar[int] = ...
    CENLEN: typing.ClassVar[int] = ...
    CENNAM: typing.ClassVar[int] = ...
    CENOFF: typing.ClassVar[int] = ...
    CENSIG: typing.ClassVar[int] = ...
    CENSIZ: typing.ClassVar[int] = ...
    CENTIM: typing.ClassVar[int] = ...
    CENVEM: typing.ClassVar[int] = ...
    CENVER: typing.ClassVar[int] = ...
    ENDCOM: typing.ClassVar[int] = ...
    ENDHDR: typing.ClassVar[int] = ...
    ENDOFF: typing.ClassVar[int] = ...
    ENDSIG: typing.ClassVar[int] = ...
    ENDSIZ: typing.ClassVar[int] = ...
    ENDSUB: typing.ClassVar[int] = ...
    ENDTOT: typing.ClassVar[int] = ...
    EXTCRC: typing.ClassVar[int] = ...
    EXTHDR: typing.ClassVar[int] = ...
    EXTLEN: typing.ClassVar[int] = ...
    EXTSIG: typing.ClassVar[int] = ...
    EXTSIZ: typing.ClassVar[int] = ...
    LOCCRC: typing.ClassVar[int] = ...
    LOCEXT: typing.ClassVar[int] = ...
    LOCFLG: typing.ClassVar[int] = ...
    LOCHDR: typing.ClassVar[int] = ...
    LOCHOW: typing.ClassVar[int] = ...
    LOCLEN: typing.ClassVar[int] = ...
    LOCNAM: typing.ClassVar[int] = ...
    LOCSIG: typing.ClassVar[int] = ...
    LOCSIZ: typing.ClassVar[int] = ...
    LOCTIM: typing.ClassVar[int] = ...
    LOCVER: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: java.io.InputStream, charset: java.nio.charset.Charset, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def closeEntry(self) -> None: ...
    def createZipEntry(self, name: str | java.lang.String, /) -> ZipEntry: ...
    def getNextEntry(self) -> ZipEntry: ...
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class ZipOutputStream(DeflaterOutputStream):
    CENATT: typing.ClassVar[int] = ...
    CENATX: typing.ClassVar[int] = ...
    CENCOM: typing.ClassVar[int] = ...
    CENCRC: typing.ClassVar[int] = ...
    CENDSK: typing.ClassVar[int] = ...
    CENEXT: typing.ClassVar[int] = ...
    CENFLG: typing.ClassVar[int] = ...
    CENHDR: typing.ClassVar[int] = ...
    CENHOW: typing.ClassVar[int] = ...
    CENLEN: typing.ClassVar[int] = ...
    CENNAM: typing.ClassVar[int] = ...
    CENOFF: typing.ClassVar[int] = ...
    CENSIG: typing.ClassVar[int] = ...
    CENSIZ: typing.ClassVar[int] = ...
    CENTIM: typing.ClassVar[int] = ...
    CENVEM: typing.ClassVar[int] = ...
    CENVER: typing.ClassVar[int] = ...
    DEFLATED: typing.ClassVar[int] = ...
    ENDCOM: typing.ClassVar[int] = ...
    ENDHDR: typing.ClassVar[int] = ...
    ENDOFF: typing.ClassVar[int] = ...
    ENDSIG: typing.ClassVar[int] = ...
    ENDSIZ: typing.ClassVar[int] = ...
    ENDSUB: typing.ClassVar[int] = ...
    ENDTOT: typing.ClassVar[int] = ...
    EXTCRC: typing.ClassVar[int] = ...
    EXTHDR: typing.ClassVar[int] = ...
    EXTLEN: typing.ClassVar[int] = ...
    EXTSIG: typing.ClassVar[int] = ...
    EXTSIZ: typing.ClassVar[int] = ...
    LOCCRC: typing.ClassVar[int] = ...
    LOCEXT: typing.ClassVar[int] = ...
    LOCFLG: typing.ClassVar[int] = ...
    LOCHDR: typing.ClassVar[int] = ...
    LOCHOW: typing.ClassVar[int] = ...
    LOCLEN: typing.ClassVar[int] = ...
    LOCNAM: typing.ClassVar[int] = ...
    LOCSIG: typing.ClassVar[int] = ...
    LOCSIZ: typing.ClassVar[int] = ...
    LOCTIM: typing.ClassVar[int] = ...
    LOCVER: typing.ClassVar[int] = ...
    STORED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: java.io.OutputStream, charset: java.nio.charset.Charset, /) -> None: ...
    def close(self) -> None: ...
    def closeEntry(self) -> None: ...
    def finish(self) -> None: ...
    def putNextEntry(self, e: ZipEntry, /) -> None: ...
    def setComment(self, comment: str | java.lang.String, /) -> None: ...
    def setLevel(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMethod(self, method: int | java.jint | java.lang.Integer, /) -> None: ...
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.content.res
import android.os
import java
import java.lang
import java.util

class FabricatedOverlay(java.lang.Object):
    def __init__(self, overlayName: str | java.lang.String, targetPackage: str | java.lang.String, /) -> None: ...
    def getIdentifier(self) -> OverlayIdentifier: ...
    def setNinePatchResourceValue(self, resourceName: str | java.lang.String, value: android.os.ParcelFileDescriptor, configuration: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setResourceValue(self, resourceName: str | java.lang.String, value: android.content.res.AssetFileDescriptor, configuration: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setResourceValue(self, resourceName: str | java.lang.String, value: android.os.ParcelFileDescriptor, configuration: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setResourceValue(self, resourceName: str | java.lang.String, dataType: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, configuration: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setResourceValue(self, resourceName: str | java.lang.String, dataType: int | java.jint | java.lang.Integer, value: str | java.lang.String, configuration: str | java.lang.String, /) -> None: ...
    def setTargetOverlayable(self, targetOverlayable: str | java.lang.String, /) -> None: ...

class OverlayIdentifier(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[OverlayIdentifier]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class OverlayInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[OverlayInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOverlayIdentifier(self) -> OverlayIdentifier: ...
    def getOverlayName(self) -> str | None: ...
    def getTargetOverlayableName(self) -> str | None: ...
    def getTargetPackageName(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class OverlayManager(java.lang.Object):
    def commit(self, transaction: OverlayManagerTransaction, /) -> None: ...
    def getOverlayInfosForTarget(self, targetPackageName: str | java.lang.String, /) -> java.util.List[OverlayInfo]: ...

class OverlayManagerTransaction(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[OverlayManagerTransaction]] = ...
    def describeContents(self) -> int: ...
    @staticmethod
    def newInstance() -> OverlayManagerTransaction: ...
    def registerFabricatedOverlay(self, overlay: FabricatedOverlay, /) -> None: ...
    def toString(self) -> str: ...
    def unregisterFabricatedOverlay(self, overlay: OverlayIdentifier, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import java.lang
import java.nio.charset
import java.util

class CharsetProvider(java.lang.Object):
    def __init__(self) -> None: ...
    def charsetForName(self, arg1: str | java.lang.String, /) -> java.nio.charset.Charset: ...
    def charsets(self) -> java.util.Iterator[java.nio.charset.Charset]: ...



import typing

import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class BlobHandle(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BlobHandle]] = ...
    @staticmethod
    def createWithSha256(digest: java.chaquopy.JavaArrayJByte, label: java.lang.CharSequence, expiryTimeMillis: int | java.jlong | java.lang.Long, tag: str | java.lang.String, /) -> BlobHandle: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getExpiryTimeMillis(self) -> int: ...
    def getLabel(self) -> java.lang.CharSequence: ...
    def getSha256Digest(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTag(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BlobStoreManager(java.lang.Object):
    def abandonSession(self, sessionId: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def acquireLease(self, blobHandle: BlobHandle, descriptionResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def acquireLease(self, blobHandle: BlobHandle, description: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def acquireLease(self, blobHandle: BlobHandle, descriptionResId: int | java.jint | java.lang.Integer, leaseExpiryTimeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def acquireLease(self, blobHandle: BlobHandle, description: java.lang.CharSequence, leaseExpiryTimeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def createSession(self, blobHandle: BlobHandle, /) -> int: ...
    def getLeasedBlobs(self) -> java.util.List[BlobHandle]: ...
    def getRemainingLeaseQuotaBytes(self) -> int: ...
    def openBlob(self, blobHandle: BlobHandle, /) -> android.os.ParcelFileDescriptor: ...
    def openSession(self, sessionId: int | java.jlong | java.lang.Long, /) -> BlobStoreManager.Session: ...
    def releaseLease(self, blobHandle: BlobHandle, /) -> None: ...

    class Session(java.io.Closeable):
        def abandon(self) -> None: ...
        def allowPackageAccess(self, packageName: str | java.lang.String, certificate: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def allowPublicAccess(self) -> None: ...
        def allowSameSignatureAccess(self) -> None: ...
        def close(self) -> None: ...
        def commit(self, executor: java.util.concurrent.Executor, resultCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
        def getSize(self) -> int: ...
        def isPackageAccessAllowed(self, packageName: str | java.lang.String, certificate: java.chaquopy.JavaArrayJByte, /) -> bool: ...
        def isPublicAccessAllowed(self) -> bool: ...
        def isSameSignatureAccessAllowed(self) -> bool: ...
        def openRead(self) -> android.os.ParcelFileDescriptor: ...
        def openWrite(self, offsetBytes: int | java.jlong | java.lang.Long, lengthBytes: int | java.jlong | java.lang.Long, /) -> android.os.ParcelFileDescriptor: ...



import typing

import java.io
import java.lang

class ConnectTimeoutException(java.io.InterruptedIOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...



import typing

import android.app
import android.os
import android.telephony
import java
import java.chaquopy
import java.lang
import java.util

class GsmCellLocation(android.telephony.CellLocation):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, bundle: android.os.Bundle, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def fillInNotifierBundle(self, m: android.os.Bundle, /) -> None: ...
    def getCid(self) -> int: ...
    def getLac(self) -> int: ...
    def getPsc(self) -> int: ...
    def hashCode(self) -> int: ...
    def setLacAndCid(self, lac: int | java.jint | java.lang.Integer, cid: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStateInvalid(self) -> None: ...
    def toString(self) -> str: ...

class SmsManager(java.lang.Object):
    RESULT_ERROR_GENERIC_FAILURE: typing.ClassVar[int] = ...
    RESULT_ERROR_NO_SERVICE: typing.ClassVar[int] = ...
    RESULT_ERROR_NULL_PDU: typing.ClassVar[int] = ...
    RESULT_ERROR_RADIO_OFF: typing.ClassVar[int] = ...
    STATUS_ON_SIM_FREE: typing.ClassVar[int] = ...
    STATUS_ON_SIM_READ: typing.ClassVar[int] = ...
    STATUS_ON_SIM_SENT: typing.ClassVar[int] = ...
    STATUS_ON_SIM_UNREAD: typing.ClassVar[int] = ...
    STATUS_ON_SIM_UNSENT: typing.ClassVar[int] = ...
    def divideMessage(self, text: str | java.lang.String, /) -> java.util.ArrayList[java.lang.String]: ...
    @staticmethod
    def getDefault() -> SmsManager: ...
    def sendDataMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, destinationPort: int | java.jshort | java.lang.Short, data: java.chaquopy.JavaArrayJByte, sentIntent: android.app.PendingIntent, deliveryIntent: android.app.PendingIntent, /) -> None: ...
    def sendMultipartTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, parts: java.util.ArrayList[java.lang.String], sentIntents: java.util.ArrayList[android.app.PendingIntent], deliveryIntents: java.util.ArrayList[android.app.PendingIntent], /) -> None: ...
    def sendTextMessage(self, destinationAddress: str | java.lang.String, scAddress: str | java.lang.String, text: str | java.lang.String, sentIntent: android.app.PendingIntent, deliveryIntent: android.app.PendingIntent, /) -> None: ...

class SmsMessage(java.lang.Object):
    ENCODING_16BIT: typing.ClassVar[int] = ...
    ENCODING_7BIT: typing.ClassVar[int] = ...
    ENCODING_8BIT: typing.ClassVar[int] = ...
    ENCODING_UNKNOWN: typing.ClassVar[int] = ...
    MAX_USER_DATA_BYTES: typing.ClassVar[int] = ...
    MAX_USER_DATA_SEPTETS: typing.ClassVar[int] = ...
    MAX_USER_DATA_SEPTETS_WITH_HEADER: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def calculateLength(messageBody: java.lang.CharSequence, use7bitOnly: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArrayJInt: ...
    @typing.overload
    @staticmethod
    def calculateLength(messageBody: str | java.lang.String, use7bitOnly: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArrayJInt: ...
    @staticmethod
    def createFromPdu(pdu: java.chaquopy.JavaArrayJByte, /) -> SmsMessage: ...
    def getDisplayMessageBody(self) -> str: ...
    def getDisplayOriginatingAddress(self) -> str: ...
    def getEmailBody(self) -> str: ...
    def getEmailFrom(self) -> str: ...
    def getIndexOnSim(self) -> int: ...
    def getMessageBody(self) -> str | None: ...
    def getMessageClass(self) -> SmsMessage.MessageClass: ...
    def getOriginatingAddress(self) -> str: ...
    def getPdu(self) -> java.chaquopy.JavaArrayJByte: ...
    def getProtocolIdentifier(self) -> int: ...
    def getPseudoSubject(self) -> str: ...
    def getServiceCenterAddress(self) -> str: ...
    def getStatus(self) -> int: ...
    def getStatusOnSim(self) -> int: ...
    @typing.overload
    @staticmethod
    def getSubmitPdu(scAddress: str | java.lang.String, destinationAddress: str | java.lang.String, message: str | java.lang.String, statusReportRequested: bool | java.jboolean | java.lang.Boolean, /) -> SmsMessage.SubmitPdu | None: ...
    @typing.overload
    @staticmethod
    def getSubmitPdu(scAddress: str | java.lang.String, destinationAddress: str | java.lang.String, destinationPort: int | java.jshort | java.lang.Short, data: java.chaquopy.JavaArrayJByte, statusReportRequested: bool | java.jboolean | java.lang.Boolean, /) -> SmsMessage.SubmitPdu | None: ...
    @staticmethod
    def getTPLayerLengthForPDU(pdu: str | java.lang.String, /) -> int: ...
    def getTimestampMillis(self) -> int: ...
    def getUserData(self) -> java.chaquopy.JavaArrayJByte: ...
    def isCphsMwiMessage(self) -> bool: ...
    def isEmail(self) -> bool: ...
    def isMWIClearMessage(self) -> bool: ...
    def isMWISetMessage(self) -> bool: ...
    def isMwiDontStore(self) -> bool: ...
    def isReplace(self) -> bool: ...
    def isReplyPathPresent(self) -> bool: ...
    def isStatusReportMessage(self) -> bool: ...

    class SubmitPdu(java.lang.Object):
        encodedMessage: java.chaquopy.JavaArrayJByte = ...
        encodedScAddress: java.chaquopy.JavaArrayJByte = ...
        def __init__(self) -> None: ...
        def toString(self) -> str: ...

    class MessageClass(java.lang.Enum[SmsMessage.MessageClass]):
        CLASS_0: typing.ClassVar[SmsMessage.MessageClass] = ...
        CLASS_1: typing.ClassVar[SmsMessage.MessageClass] = ...
        CLASS_2: typing.ClassVar[SmsMessage.MessageClass] = ...
        CLASS_3: typing.ClassVar[SmsMessage.MessageClass] = ...
        UNKNOWN: typing.ClassVar[SmsMessage.MessageClass] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> SmsMessage.MessageClass: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[SmsMessage.MessageClass]: ...



import typing

import java
import java.chaquopy
import java.lang
import java.math
import java.security
import java.security.interfaces
import java.util

class AlgorithmParameterSpec(java.lang.Object): ...

class DSAGenParameterSpec(AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, primePLen: int | java.jint | java.lang.Integer, subprimeQLen: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, primePLen: int | java.jint | java.lang.Integer, subprimeQLen: int | java.jint | java.lang.Integer, seedLen: int | java.jint | java.lang.Integer, /) -> None: ...
    def getPrimePLength(self) -> int: ...
    def getSeedLength(self) -> int: ...
    def getSubprimeQLength(self) -> int: ...

class DSAParameterSpec(AlgorithmParameterSpec, java.security.interfaces.DSAParams):
    def __init__(self, p: java.math.BigInteger, q: java.math.BigInteger, g: java.math.BigInteger, /) -> None: ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...

class DSAPrivateKeySpec(KeySpec):
    def __init__(self, x: java.math.BigInteger, p: java.math.BigInteger, q: java.math.BigInteger, g: java.math.BigInteger, /) -> None: ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...
    def getX(self) -> java.math.BigInteger: ...

class DSAPublicKeySpec(KeySpec):
    def __init__(self, y: java.math.BigInteger, p: java.math.BigInteger, q: java.math.BigInteger, g: java.math.BigInteger, /) -> None: ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...
    def getY(self) -> java.math.BigInteger: ...

class ECField(java.lang.Object):
    def getFieldSize(self) -> int: ...

class ECFieldF2m(ECField):
    @typing.overload
    def __init__(self, m: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, m: int | java.jint | java.lang.Integer, rp: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, m: int | java.jint | java.lang.Integer, ks: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFieldSize(self) -> int: ...
    def getM(self) -> int: ...
    def getMidTermsOfReductionPolynomial(self) -> java.chaquopy.JavaArrayJInt: ...
    def getReductionPolynomial(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...

class ECFieldFp(ECField):
    def __init__(self, p: java.math.BigInteger, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFieldSize(self) -> int: ...
    def getP(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...

class ECGenParameterSpec(NamedParameterSpec, AlgorithmParameterSpec):
    def __init__(self, stdName: str | java.lang.String, /) -> None: ...
    def getName(self) -> str: ...

class ECParameterSpec(AlgorithmParameterSpec):
    def __init__(self, curve: EllipticCurve, g: ECPoint, n: java.math.BigInteger, h: int | java.jint | java.lang.Integer, /) -> None: ...
    def getCofactor(self) -> int: ...
    def getCurve(self) -> EllipticCurve: ...
    def getGenerator(self) -> ECPoint: ...
    def getOrder(self) -> java.math.BigInteger: ...

class ECPoint(java.lang.Object):
    POINT_INFINITY: typing.ClassVar[ECPoint] = ...
    def __init__(self, x: java.math.BigInteger, y: java.math.BigInteger, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAffineX(self) -> java.math.BigInteger: ...
    def getAffineY(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...

class ECPrivateKeySpec(KeySpec):
    def __init__(self, s: java.math.BigInteger, params: ECParameterSpec, /) -> None: ...
    def getParams(self) -> ECParameterSpec: ...
    def getS(self) -> java.math.BigInteger: ...

class ECPublicKeySpec(KeySpec):
    def __init__(self, w: ECPoint, params: ECParameterSpec, /) -> None: ...
    def getParams(self) -> ECParameterSpec: ...
    def getW(self) -> ECPoint: ...

class EdDSAParameterSpec(AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, prehash: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, prehash: bool | java.jboolean | java.lang.Boolean, context: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def getContext(self) -> java.util.Optional[java.chaquopy.JavaArrayJByte]: ...
    def isPrehash(self) -> bool: ...

class EdECPoint(java.lang.Object):
    def __init__(self, xOdd: bool | java.jboolean | java.lang.Boolean, y: java.math.BigInteger, /) -> None: ...
    def getY(self) -> java.math.BigInteger: ...
    def isXOdd(self) -> bool: ...

class EdECPrivateKeySpec(KeySpec):
    def __init__(self, params: NamedParameterSpec, bytes: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def getBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def getParams(self) -> NamedParameterSpec: ...

class EdECPublicKeySpec(KeySpec):
    def __init__(self, params: NamedParameterSpec, point: EdECPoint, /) -> None: ...
    def getParams(self) -> NamedParameterSpec: ...
    def getPoint(self) -> EdECPoint: ...

class EllipticCurve(java.lang.Object):
    @typing.overload
    def __init__(self, field: ECField, a: java.math.BigInteger, b: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, field: ECField, a: java.math.BigInteger, b: java.math.BigInteger, seed: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getA(self) -> java.math.BigInteger: ...
    def getB(self) -> java.math.BigInteger: ...
    def getField(self) -> ECField: ...
    def getSeed(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...

class EncodedKeySpec(KeySpec):
    @typing.overload
    def __init__(self, encodedKey: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, encodedKey: java.chaquopy.JavaArrayJByte, algorithm: str | java.lang.String, /) -> None: ...
    def getAlgorithm(self) -> str: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getFormat(self) -> str: ...

class InvalidKeySpecException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class InvalidParameterSpecException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class KeySpec(java.lang.Object): ...

class MGF1ParameterSpec(AlgorithmParameterSpec):
    SHA1: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA224: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA256: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA384: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA3_224: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA3_256: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA3_384: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA3_512: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA512: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA512_224: typing.ClassVar[MGF1ParameterSpec] = ...
    SHA512_256: typing.ClassVar[MGF1ParameterSpec] = ...
    def __init__(self, mdName: str | java.lang.String, /) -> None: ...
    def getDigestAlgorithm(self) -> str: ...
    def toString(self) -> str: ...

class NamedParameterSpec(AlgorithmParameterSpec):
    ED25519: typing.ClassVar[NamedParameterSpec] = ...
    ED448: typing.ClassVar[NamedParameterSpec] = ...
    X25519: typing.ClassVar[NamedParameterSpec] = ...
    X448: typing.ClassVar[NamedParameterSpec] = ...
    def __init__(self, stdName: str | java.lang.String, /) -> None: ...
    def getName(self) -> str: ...

class PKCS8EncodedKeySpec(EncodedKeySpec):
    @typing.overload
    def __init__(self, encodedKey: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, encodedKey: java.chaquopy.JavaArrayJByte, algorithm: str | java.lang.String, /) -> None: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getFormat(self) -> str: ...

class PSSParameterSpec(AlgorithmParameterSpec):
    DEFAULT: typing.ClassVar[PSSParameterSpec] = ...
    TRAILER_FIELD_BC: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, saltLen: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, mdName: str | java.lang.String, mgfName: str | java.lang.String, mgfSpec: AlgorithmParameterSpec, saltLen: int | java.jint | java.lang.Integer, trailerField: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDigestAlgorithm(self) -> str: ...
    def getMGFAlgorithm(self) -> str: ...
    def getMGFParameters(self) -> AlgorithmParameterSpec: ...
    def getSaltLength(self) -> int: ...
    def getTrailerField(self) -> int: ...
    def toString(self) -> str: ...

class RSAKeyGenParameterSpec(AlgorithmParameterSpec):
    F0: typing.ClassVar[java.math.BigInteger] = ...
    F4: typing.ClassVar[java.math.BigInteger] = ...
    @typing.overload
    def __init__(self, keysize: int | java.jint | java.lang.Integer, publicExponent: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, keysize: int | java.jint | java.lang.Integer, publicExponent: java.math.BigInteger, keyParams: AlgorithmParameterSpec, /) -> None: ...
    def getKeyParams(self) -> AlgorithmParameterSpec: ...
    def getKeysize(self) -> int: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAMultiPrimePrivateCrtKeySpec(RSAPrivateKeySpec):
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, publicExponent: java.math.BigInteger, privateExponent: java.math.BigInteger, primeP: java.math.BigInteger, primeQ: java.math.BigInteger, primeExponentP: java.math.BigInteger, primeExponentQ: java.math.BigInteger, crtCoefficient: java.math.BigInteger, otherPrimeInfo: java.chaquopy.JavaArray[RSAOtherPrimeInfo], /) -> None: ...
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, publicExponent: java.math.BigInteger, privateExponent: java.math.BigInteger, primeP: java.math.BigInteger, primeQ: java.math.BigInteger, primeExponentP: java.math.BigInteger, primeExponentQ: java.math.BigInteger, crtCoefficient: java.math.BigInteger, otherPrimeInfo: java.chaquopy.JavaArray[RSAOtherPrimeInfo], keyParams: AlgorithmParameterSpec, /) -> None: ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getOtherPrimeInfo(self) -> java.chaquopy.JavaArray[RSAOtherPrimeInfo]: ...
    def getPrimeExponentP(self) -> java.math.BigInteger: ...
    def getPrimeExponentQ(self) -> java.math.BigInteger: ...
    def getPrimeP(self) -> java.math.BigInteger: ...
    def getPrimeQ(self) -> java.math.BigInteger: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAOtherPrimeInfo(java.lang.Object):
    def __init__(self, prime: java.math.BigInteger, primeExponent: java.math.BigInteger, crtCoefficient: java.math.BigInteger, /) -> None: ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getExponent(self) -> java.math.BigInteger: ...
    def getPrime(self) -> java.math.BigInteger: ...

class RSAPrivateCrtKeySpec(RSAPrivateKeySpec):
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, publicExponent: java.math.BigInteger, privateExponent: java.math.BigInteger, primeP: java.math.BigInteger, primeQ: java.math.BigInteger, primeExponentP: java.math.BigInteger, primeExponentQ: java.math.BigInteger, crtCoefficient: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, publicExponent: java.math.BigInteger, privateExponent: java.math.BigInteger, primeP: java.math.BigInteger, primeQ: java.math.BigInteger, primeExponentP: java.math.BigInteger, primeExponentQ: java.math.BigInteger, crtCoefficient: java.math.BigInteger, keyParams: AlgorithmParameterSpec, /) -> None: ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getPrimeExponentP(self) -> java.math.BigInteger: ...
    def getPrimeExponentQ(self) -> java.math.BigInteger: ...
    def getPrimeP(self) -> java.math.BigInteger: ...
    def getPrimeQ(self) -> java.math.BigInteger: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAPrivateKeySpec(KeySpec):
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, privateExponent: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, privateExponent: java.math.BigInteger, params: AlgorithmParameterSpec, /) -> None: ...
    def getModulus(self) -> java.math.BigInteger: ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getPrivateExponent(self) -> java.math.BigInteger: ...

class RSAPublicKeySpec(KeySpec):
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, publicExponent: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def __init__(self, modulus: java.math.BigInteger, publicExponent: java.math.BigInteger, params: AlgorithmParameterSpec, /) -> None: ...
    def getModulus(self) -> java.math.BigInteger: ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class X509EncodedKeySpec(EncodedKeySpec):
    @typing.overload
    def __init__(self, encodedKey: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, encodedKey: java.chaquopy.JavaArrayJByte, algorithm: str | java.lang.String, /) -> None: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getFormat(self) -> str: ...

class XECPrivateKeySpec(KeySpec):
    def __init__(self, params: AlgorithmParameterSpec, scalar: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getScalar(self) -> java.chaquopy.JavaArrayJByte: ...

class XECPublicKeySpec(KeySpec):
    def __init__(self, params: AlgorithmParameterSpec, u: java.math.BigInteger, /) -> None: ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getU(self) -> java.math.BigInteger: ...
